@@ -32,6 +32,7 @@ from TechParser import threednews
 from TechParser import ixbt
 from TechParser import mobilereview
 from TechParser import helpix
+from TechParser import recode
 
 sites_to_parse = {
 		"Habrahabr": { # habrahabr.ru
@@ -188,6 +189,11 @@ sites_to_parse = {
 		"Helpix": { # helpix.ru
 			"module": helpix,
 			"kwargs": {}
+		},
+		
+		"Re/code": { # recode.net
+			"module": recode,
+			"kwargs": {}
 		}
 	}
 
@@ -201,6 +207,12 @@ filters = {
 
 update_interval = 1800 # Parse articles every 30 minutes
 
+# Database for keeping history
+# must be sqlite or postgresql.
+# If You're using postgresql make sure
+# to set environment variable DATABASE_URL
+# like this: postgres://user:password@host:port/dbname
+db = 'sqlite'
 host = "0.0.0.0" # Server host
 port = "8080" # Server port
 
